pyCARLANeT
===============
## Introduction
pyCARLANeT is the carla side of the open source library CARLANeT for the co-simulation between CARLA and OMNeT++.

## Requirements

According to the [CARLA documentation](https://carla.readthedocs.io/en/latest/start_quickstart/), pyCARLANeT is compatible with Python version 3.8.x and pip version greater than 22.x. To upgrade pip, you can use:
```shell
pip install --upgrade pip==22.*
```

## Installation
You can install **pyCARLANeT** directly from [pypi](https://pypi.org/project/pycarlanet/). 
```shell
pip install pycarlanet
```

## Usage
To learn how to utilize this library, refer to the [sample code provided](https://github.com/carlanet/pycarlanet/blob/main/sample/sample_car_light.py).
A preliminary version of the documentation will be available soon.
